summaryrefslogtreecommitdiffstats
path: root/cpukit/posix/src/prwlocktimedwrlock.c
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2015-07-28 14:45:42 +0200
committerSebastian Huber <sebastian.huber@embedded-brains.de>2015-07-28 14:54:51 +0200
commit21789a2117f7485000e0d88c3f76a6b9d507bb5a (patch)
treef14a8eee3d9c10fd673c43f55f7a50d9b5b58b05 /cpukit/posix/src/prwlocktimedwrlock.c
parentm68k: Include proper header file (diff)
downloadrtems-21789a2117f7485000e0d88c3f76a6b9d507bb5a.tar.bz2
score: Rename _POSIX_Absolute_timeout_to_ticks()
Rename _POSIX_Absolute_timeout_to_ticks() to _TOD_Absolute_timeout_to_ticks() and move it to the score directory. Delete empty <rtems/posix/time.h>.
Diffstat (limited to 'cpukit/posix/src/prwlocktimedwrlock.c')
-rw-r--r--cpukit/posix/src/prwlocktimedwrlock.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/cpukit/posix/src/prwlocktimedwrlock.c b/cpukit/posix/src/prwlocktimedwrlock.c
index 2f192d4045..f387dc3835 100644
--- a/cpukit/posix/src/prwlocktimedwrlock.c
+++ b/cpukit/posix/src/prwlocktimedwrlock.c
@@ -24,8 +24,8 @@
#include <errno.h>
#include <rtems/posix/rwlockimpl.h>
-#include <rtems/posix/time.h>
#include <rtems/score/thread.h>
+#include <rtems/score/todimpl.h>
/*
* pthread_rwlock_timedwrlock
@@ -49,7 +49,7 @@ int pthread_rwlock_timedwrlock(
Objects_Locations location;
Watchdog_Interval ticks;
bool do_wait = true;
- POSIX_Absolute_timeout_conversion_results_t status;
+ TOD_Absolute_timeout_conversion_results status;
Thread_Control *executing;
/*
@@ -61,12 +61,12 @@ int pthread_rwlock_timedwrlock(
* then we do a polling operation and convert the UNSATISFIED
* status into the appropriate error.
*
* If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
* POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/
- status = _POSIX_Absolute_timeout_to_ticks( abstime, &ticks );
- if ( status != POSIX_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
+ status = _TOD_Absolute_timeout_to_ticks( abstime, &ticks );
+ if ( status != TOD_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
do_wait = false;
the_rwlock = _POSIX_RWLock_Get( rwlock, &location );
@@ -87,10 +87,10 @@ int pthread_rwlock_timedwrlock(
_Objects_Put( &the_rwlock->Object );
if ( !do_wait &&
(executing->Wait.return_code == CORE_RWLOCK_UNAVAILABLE) ) {
- if ( status == POSIX_ABSOLUTE_TIMEOUT_INVALID )
+ if ( status == TOD_ABSOLUTE_TIMEOUT_INVALID )
return EINVAL;
- if ( status == POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST ||
- status == POSIX_ABSOLUTE_TIMEOUT_IS_NOW )
+ if ( status == TOD_ABSOLUTE_TIMEOUT_IS_IN_PAST ||
+ status == TOD_ABSOLUTE_TIMEOUT_IS_NOW )
return ETIMEDOUT;
}
@@ -61,12 +61,12 @@ int pthread_rwlock_timedwrlock(
* status into the appropriate error.
*
- * If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
- * POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
+ * If the status is TOD_ABSOLUTE_TIMEOUT_INVALID,
+ * TOD_ABSOLUTE_TIMEOUT_IS_IN_PAST, or TOD_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/